@@ -70,6 +70,10 @@ def verilogify(
     context.py_func = func
     context.py_string = inspect.getsource(func)
 
+    for name in func_ast.args.args:
+        assert not name.arg.startswith(
+            "_"
+        ), f'Parameter beginning with "_" are reserved {name.arg}'
     context.input_vars = [ir.Var(name.arg) for name in func_ast.args.args]
 
     context.mode = mode
@@ -158,7 +162,7 @@ def verilogify(
                 "Keyword arguments not yet supported, use positional arguments only"
             )
         for arg in args:
-            assert guard(arg, int)
+            assert guard(arg, int), "Only `int` type arguments are supported"
 
         context.test_cases.append(args)
 
@@ -233,17 +237,20 @@ def get_expected(
     """
     Get expected output of testbench
 
-    Limits number of values generator can yield
+    Limits number of values generators can yield
     """
-    generator_func = get_original_func(verilogified)
+    func = get_original_func(verilogified)
     for test in get_context(verilogified).test_cases:
         logging.debug("Test case %s", test)
-        for i, value in enumerate(generator_func(*test)):
-            yield value
-            if i > max_yields_per_test_case:
-                raise RuntimeError(
-                    f"Generator yielded more than {max_yields_per_test_case} values"
-                )
+        if get_context(verilogified).is_generator:
+            for i, value in enumerate(func(*test)):
+                yield value
+                if i > max_yields_per_test_case:
+                    raise RuntimeError(
+                        f"Generator yielded more than {max_yields_per_test_case} values"
+                    )
+        else:
+            yield func(*test)
 
 
 def get_actual_raw(
